# Copyright (C) 2009 Canonical Ltd 

import os.path
import sys


from launchpadlib.credentials import Credentials

from launchpadlib.launchpad import (
    Launchpad, STAGING_SERVICE_ROOT,
    EDGE_SERVICE_ROOT,
    )

service_root = os.environ.get('LAUNCHPAD_API', EDGE_SERVICE_ROOT)


def trace(s):
    sys.stderr.write(s + '\n')


def create_session():
    lplib_cachedir = os.path.expanduser("~/.cache/launchpadlib/")
    hydrazine_cachedir = os.path.expanduser("~/.cache/hydrazine/")
    rrd_dir = os.path.expanduser("~/.cache/hydrazine/rrd")
    for d in [lplib_cachedir, hydrazine_cachedir, rrd_dir]:
        if not os.path.isdir(d):
            os.makedirs(d, mode=0700)


    hydrazine_credentials_filename = os.path.join(hydrazine_cachedir,
        'credentials')
    if os.path.exists(hydrazine_credentials_filename):
        credentials = Credentials()
        credentials.load(file(
            os.path.expanduser("~/.cache/hydrazine/credentials"),
            "r"))
        trace('loaded existing credentials')
        return Launchpad(credentials, service_root,
            lplib_cachedir)
        # TODO: handle the case of having credentials that have expired etc
    else:
        launchpad = Launchpad.get_token_and_login(
            'Hydrazine',
            service_root,
            lplib_cachedir)
        trace('saving credentials...')
        launchpad.credentials.save(file(
            hydrazine_credentials_filename,
            "w"))
        return launchpad



def web_url(api_url):
    """Turn the api url into something you can use in a browser."""
    # see https://bugs.edge.launchpad.net/launchpadlib/+bug/316694

    return api_url.replace("api.", "", 1). \
        replace("beta/", "", 1)
